# Code of Conduct

This project adheres to the Contributor Covenant Code of Conduct (v2.1).
By participating, you are expected to uphold this code.

- Be respectful and inclusive.
- Assume good faith and be constructive.
- No harassment, hate, or discrimination.
- Focus on collaboration and technical merits.

Enforcement contacts: hal.long@outlook.com

For the full text, see:
https://www.contributor-covenant.org/version/2/1/code_of_conduct/

Attribution: This Code of Conduct is adapted from the Contributor Covenant, version 2.1.

